@@ -3,6 +3,9 @@ from optparse import OptionParser
 import minimock
 
 FIXTURE_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'fixtures')
+TEST_URL = 'http://svn.freia.jp/open/zope2docs/branches'
+TEST_REVS = [516,632,655,664,667,668,670]
+TEST_MAX_REV = TEST_REVS[-1]
 
 svn_command_parser = OptionParser()
 svn_command_parser.add_option('-r', '--revision',
@@ -21,29 +24,31 @@ def command(cmd):
     #if 'dummy-url' not in cmd:
     #    return command_orig(cmd)
 
+    options, args = svn_command_parser.parse_args(cmd[2:])
+    if options.change:
+        rev = options.change
+    elif options.revision:
+        rev = options.revision.replace(':','-')
+    else:
+        rev = '1-HEAD'
+
     if 'info' == cmd[1]:
-        return open(os.path.join(FIXTURE_DIR, 'info-1.xml')).read(), ''
+        return 0, open(os.path.join(FIXTURE_DIR, 'info-1.xml')).read(), ''
 
     elif 'log' == cmd[1]:
-        options, args = svn_command_parser.parse_args(cmd[2:])
-        if options.change:
-            rev = options.change
-        elif options.revision:
-            rev = options.revision.replace(':','-')
-        else:
-            rev = '1-HEAD'
         filename = 'log-%s.xml' % rev
-        if not os.path.exists(os.path.join(FIXTURE_DIR, filename)):
-            raise RuntimeError(filename+' was not found')
+        if int(rev.split('-',2)[0]) > TEST_MAX_REV:
+            return 1, '<?xml version="1.0"?><log>', ''
 
         f = os.path.join(FIXTURE_DIR, filename)
         #print f
-        return open(f).read(), ''
+        return 0, open(f).read(), ''
 
     elif 'diff' == cmd[1]:
-        f = os.path.join(FIXTURE_DIR, 'diff-1.txt')
+        filename = 'diff-%s.xml' % rev
+        f = os.path.join(FIXTURE_DIR, filename)
         #print f
-        return open(f).read(), ''
+        return 0, open(f).read(), ''
 
     else:
         raise RuntimeError("'%s' was not supported." % cmd)
@@ -65,10 +70,16 @@ class TestBase(unittest.TestCase):
         send(fromaddr, toaddrs, subject, message_text,
              smtpserver=smtpserver, charset=charset, sender=storage)
 
+    def _command(self, cmd):
+        self._cmd_hist.append(cmd)
+        print cmd # print when test failed. (nose functionality)
+        return command(cmd)
+
     def setUp(self):
         self._sent = []
+        self._cmd_hist = []
         import svnpoller.svnlog
-        minimock.mock('svnpoller.svnlog.command', mock_obj=command)
+        minimock.mock('svnpoller.svnlog.command', mock_obj=self._command)
 
     def tearDown(self):
         minimock.restore()
